/* 
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 * USA.
 */
package android.androidVNC;

import java.io.File;

import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
/**
 * <p>(Se omiten acentos)</p>
 * <p>Clase utilizada para mostrar notificaciones en la barra de estado.
 * del programa con un mismo identificador e icono.</p> 
 * <p>Notificacion.java.</p>
 * <p>Aadido al PFC en la version v0.2.5.</p>
 * <p><b>Proyecto original:</b></p>
 * 		<p>Web: http://code.google.com/p/android-vnc-viewer/.</p>
 * 		<p>Release: 39.</p>
 *	 	<p>Migrada a release 60.</p>
 * @author Alberto Poblacion Navarro
 */
public class Notificacion {
	
	/** Objeto de la clase utilizada para manejar las notificaciones */
	private NotificationManager nm;
	/** Objeto que permite lanzar devolver el foco a la aplicacion en caso de seleccionar la notificacion en la barra de estado */
	private PendingIntent contentIntent;
	/** Contexto de la aplicacion */
	private Context context;
	/** Icono de la aplicacion para indentificar las notificaciones */
	private int icon = R.drawable.icon;
	/** Identificador de las notificaciones */
	final int ID = 0;
	/** Objeto que almacena la unica instancia que debe crearse de esta clase en ejecucion. Patron Singleton */
	private static Notificacion instancia = null;
	/**
	 * Constructor publico de esta clase. Solo se va a crear una instancia por ejecucin del programa.
	 * En caso de que no se haya creado la instancia se crea un objeto nuevo, en caso contrario se devuelve el creado anteriormente.
	 * @param context Contexto de ejecucion del programa
	 * @return La instancia de la clase.
	 */
	static synchronized Notificacion Instancia(Context context){
		if (instancia == null)
			instancia = new Notificacion(context);
		return instancia;
	}
	/**
	 * Constructor privado de la clase que solo se llamara una vez por ejecucion de programa
	 * @param context_ Contexto de ejecucion
	 */
	private Notificacion(Context context_) {
		context = context_;
		//Se obtiene el servicio para manejar las notificaciones
		nm= (NotificationManager) context.getSystemService(Context.NOTIFICATION_SERVICE);
	    // PendingIntent es un Intent que lanzara nuestra actividad si el usuario seleciona la notifacion
		// en la barra de estado.
	    contentIntent = PendingIntent.getActivity(context, 0, new Intent(context,androidVNC.class), 0);
	}
	/**
	 * En caso de llamar a esta funciona la notificacion tendra el mismo titulo e informacion. 
	 * La actividad lanzada en caso de clic sobre la notificacion sera la propia ejecucion del programa
	 * @param cadena Titulo e informacion de la notificacion
	 */
	public void notificar(String cadena){
		notificar(cadena, cadena, contentIntent);
	}
	/**
	 * Publica una notificacion con un titulo e informacion pasados por parametro. 
	 * La actividad lanzada en caso de clic sobre la notificacion sera la propia ejecucion del programa.
	 * @param titulo Ttulo de la notificacion
	 * @param texto Informaion publicada en la notificacion
	 */
	public void notificar(String titulo, String texto){
		notificar(titulo, texto, contentIntent);
	}
	/**
	 * Crea una nueva notificacion con el titulo e informacion pasados por parametro.
	 * En este caso si se pica sobre la notificacion se mostrara la imagen recien creada
	 * Funcion utlizada para notificar la creacion de una captura de pantalla.
	 * @param titulo Ttulo de la notificacion
	 * @param texto Informacion publicada en la notificacion
	 * @param imagen Imagen que se mostrara si se hace clic en la notificacion
	 */
	public void notificar(String titulo, String texto, File imagen){
		//Se crea un intent para que cuando se seleccione la notificacion se abra la imagen pasada por parametro
		Intent intent= new Intent(Intent.ACTION_VIEW);
		intent.setData(Uri.fromFile(imagen));
		ComponentName comp = new ComponentName("com.android.camera","com.android.camera.ViewImage");
		intent.setComponent(comp); 
		PendingIntent pendingIntent = PendingIntent.getActivity(context, 0, intent, 0); 
		notificar(titulo, texto, pendingIntent);
	}
	/**
	 * Funcion que publicara en la barra de estado una notificacion con la informacion
	 * pasada en los parametros de la llamada.
	 * @param titulo Ttulo de la notificacion
	 * @param texto Informacion publicada en la notificacion
	 * @param pendingIntent actividad que se ejecutara si se selecciona la notificacion en la barra de estado
	 */
	private void notificar(String titulo, String texto, PendingIntent pendingIntent){
		Notification notificacion;
		//Se crea la notificacion y se configura.
		notificacion = new Notification(icon, titulo, System.currentTimeMillis());
		notificacion.setLatestEventInfo(context, titulo, texto, pendingIntent);
		//Se publica la notificacion en la barra de estado
		nm.notify(ID, notificacion);
	}
	//Se limina las notificaciones de las barras de estado.
	public void eliminar(){
		nm.cancel(ID);
	}
	
		
}
